pub enum ReadError {
ConnectionClosed,
UnexpectedMessage,
Parser(ErrMode<ContextError>),
Other(Error),
}Variants
ConnectionClosed
This is the most important error to take care of - when the connection has been closed, this is the only error that shall be returned when reading. This is so that implementors / users of the trait can handle this case consistently.
UnexpectedMessage
Parser(ErrMode<ContextError>)
Other(Error)