pub struct Message<T> {
pub content: T,
pub extra_headers: Vec<(Vec<u8>, Vec<u8>)>,
}Expand description
A representation of a STOMP frame
This struct holds the content of a STOMP message (which can be either a message sent to the server or received from the server) along with any extra headers that were present in the frame but not required by the specific message type.
Fields
content: TThe message content, which is either a ToServer or FromServer enum
extra_headers: Vec<(Vec<u8>, Vec<u8>)>Headers present in the frame which were not required by the content type Stored as raw bytes to avoid unnecessary conversions
Implementations
Sourceimpl Message<FromServer>
impl Message<FromServer>
pub fn into_bytes(self) -> Bytes
Sourceimpl Message<ToServer>
impl Message<ToServer>
Sourcepub fn into_bytes(self) -> Bytes
pub fn into_bytes(self) -> Bytes
Converts the message to a Frame and then serializes the frame as bytes. This is useful for implementors that need to implement the ClientTransport trait.